@@ -1,6 +1,6 @@
 /* Dynamically allocated strings
 
-   Copyright (c) 2001, 2002, 2003, 2004, 2005, 2008, 2009, 2010 Free Software Foundation, Inc.
+   Copyright (c) 2001, 2002, 2003, 2004, 2005, 2008, 2009, 2010, 2011 Free Software Foundation, Inc.
 
    This file is part of GNU Zile.
 
@@ -19,7 +19,7 @@
    Free Software Foundation, Fifth Floor, 51 Franklin Street, Boston,
    MA 02111-1301, USA.  */
 
-#include "config.h"
+#include <config.h>
 
 #include <assert.h>
 #include <stdarg.h>
@@ -85,7 +85,7 @@ astr_ncat_cstr (astr as, const char *s, size_t csize)
   if (as->len + csize > as->maxlen)
     {
       as->maxlen = as->len + csize + ALLOCATION_CHUNK_SIZE;
-      as->text = (char *) xrealloc (as->text, as->maxlen + 1);
+      as->text = xrealloc (as->text, as->maxlen + 1);
     }
   memcpy (as->text + as->len, s, csize);
   as->len += csize;
@@ -258,35 +258,40 @@ astr_recase (astr as, enum casing newcase)
 
 #ifdef TEST
 
+#include <config.h>
+
 #include <stdio.h>
+#include "progname.h"
+
+#include "main.h"
 
 static void
 assert_eq (astr as, const char *s)
 {
-  if (strcmp (astr_cstr (as), s))
+  if (STRNEQ (astr_cstr (as), s))
     {
       printf ("test failed: \"%s\" != \"%s\"\n", astr_cstr (as), s);
-      exit (1);
+      exit (EXIT_FAILURE);
     }
 }
 
-/*
- * Stubs to make xalloc_die happy.
- */
-char *prog_name = "astr";
+/* Stub to make xalloc_die happy. */
+void zile_exit (int doabort) _GL_ATTRIBUTE_NORETURN;
 
 void
-zile_exit (int doabort)
+zile_exit (int doabort _GL_UNUSED_PARAMETER)
 {
-  exit (2);
+  exit (EXIT_CRASH);
 }
 
 
 int
-main (void)
+main (int argc _GL_UNUSED_PARAMETER, char **argv)
 {
   astr as1, as2, as3;
 
+  set_program_name (argv[0]);
+
   as1 = astr_new ();
   astr_cpy_cstr (as1, "hello world");
   astr_cat_char (as1, '!');
@@ -369,7 +374,7 @@ main (void)
   astr_delete (as3);
   printf ("astr test successful.\n");
 
-  return 0;
+  return EXIT_SUCCESS;
 }
 
 #endif /* TEST */
