@@ -1,6 +1,6 @@
 /* Basic movement functions
 
-   Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2008, 2009 Free Software Foundation, Inc.
+   Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2008, 2009, 2011 Free Software Foundation, Inc.
 
    This file is part of GNU Zile.
 
@@ -19,13 +19,12 @@
    Free Software Foundation, Fifth Floor, 51 Franklin Street, Boston,
    MA 02111-1301, USA.  */
 
-#include "config.h"
+#include <config.h>
 
 #include <limits.h>
 #include <stdarg.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <string.h>
 
 #include "main.h"
 #include "extern.h"
@@ -136,10 +135,10 @@ move_line (int n)
 
   for (; n > 0; n--)
     {
-      Point pt = get_buffer_pt (cur_bp);
-      pt.p = (dir > 0 ? get_line_next : get_line_prev) (pt.p);
-      pt.n += dir;
-      set_buffer_pt (cur_bp, pt);
+      Point pt2 = get_buffer_pt (cur_bp);
+      pt2.p = (dir > 0 ? get_line_next : get_line_prev) (pt2.p);
+      pt2.n += dir;
+      set_buffer_pt (cur_bp, pt2);
     }
 
   if (last_command () != F_next_line && last_command () != F_previous_line)
@@ -269,7 +268,8 @@ DEFUN ("beginning-of-buffer", beginning_of_buffer)
 Move point to the beginning of the buffer; leave mark at previous position.
 +*/
 {
-  set_mark_interactive ();
+  if (!get_variable_bool ("transient-mark-mode"))
+    set_mark_interactive ();
   gotobob ();
 }
 END_DEFUN
@@ -289,7 +289,8 @@ DEFUN ("end-of-buffer", end_of_buffer)
 Move point to the end of the buffer; leave mark at previous position.
 +*/
 {
-  set_mark_interactive ();
+  if (!get_variable_bool ("transient-mark-mode"))
+    set_mark_interactive ();
   gotoeob ();
 }
 END_DEFUN
