@@ -1,6 +1,6 @@
 /* Key bindings and extended commands
 
-   Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 Free Software Foundation, Inc.
+   Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software Foundation, Inc.
 
    This file is part of GNU Zile.
 
@@ -19,14 +19,13 @@
    Free Software Foundation, Fifth Floor, 51 Franklin Street, Boston,
    MA 02111-1301, USA.  */
 
-#include "config.h"
+#include <config.h>
 
 #include <assert.h>
 #include <ctype.h>
 #include <stdarg.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <string.h>
 #include "gl_array_list.h"
 #include "gl_linked_list.h"
 
@@ -85,7 +84,7 @@ add_node (Binding tree, Binding p)
   if (tree->vecnum + 1 >= tree->vecmax)
     {
       tree->vecmax += 5;
-      tree->vec = (Binding *) xrealloc (tree->vec, sizeof (*p) * tree->vecmax);
+      tree->vec = xrealloc (tree->vec, sizeof (*p) * tree->vecmax);
     }
 
   /* Insert the node. */
@@ -518,14 +517,14 @@ walk_bindings_tree (Binding tree, gl_list_t keys,
       if (p->func != NULL)
         {
           astr key = astr_new ();
-          astr as = chordtostr (p->key);
+          astr bs = chordtostr (p->key);
           for (j = 1; j < gl_list_size (keys); j++)
             {
               astr_cat (key, (astr) gl_list_get_at (keys, j));
               astr_cat_char (key, ' ');
             }
-          astr_cat (key, as);
-          astr_delete (as);
+          astr_cat (key, bs);
+          astr_delete (bs);
           process (key, p, st);
           astr_delete (key);
         }
@@ -608,13 +607,13 @@ message in the buffer.
 END_DEFUN
 
 static void
-print_binding (astr key, Binding p, void *st GCC_UNUSED)
+print_binding (astr key, Binding p, void *st _GL_UNUSED_PARAMETER)
 {
   bprintf ("%-15s %s\n", astr_cstr (key), get_function_name (p->func));
 }
 
 static void
-write_bindings_list (va_list ap GCC_UNUSED)
+write_bindings_list (va_list ap _GL_UNUSED_PARAMETER)
 {
   bprintf ("Key translations:\n");
   bprintf ("%-15s %s\n", "key", "binding");
