@@ -1,6 +1,6 @@
 /* Buffer-oriented functions
 
-   Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2008, 2009, 2010 Free Software Foundation, Inc.
+   Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2008, 2009, 2010, 2011 Free Software Foundation, Inc.
 
    This file is part of GNU Zile.
 
@@ -19,13 +19,12 @@
    Free Software Foundation, Fifth Floor, 51 Franklin Street, Boston,
    MA 02111-1301, USA.  */
 
-#include "config.h"
+#include <config.h>
 
 #include <assert.h>
 #include <stdarg.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <string.h>
 
 #include "main.h"
 #include "extern.h"
@@ -215,7 +214,7 @@ find_buffer (const char *name)
   for (bp = head_bp; bp != NULL; bp = bp->next)
     {
       const char *bname = get_buffer_name (bp);
-      if (bname && !strcmp (bname, name))
+      if (bname && STREQ (bname, name))
         return bp;
     }
 
@@ -291,7 +290,8 @@ warn_if_no_mark (void)
       minibuf_error ("The mark is not set now");
       return true;
     }
-  else if (!get_buffer_mark_active (cur_bp) && transient_mark_mode ())
+  else if (!get_buffer_mark_active (cur_bp) &&
+           get_variable_bool ("transient-mark-mode"))
     {
       minibuf_error ("The mark is not active now");
       return true;
@@ -433,12 +433,6 @@ calculate_buffer_size (Buffer * bp)
   return size;
 }
 
-int
-transient_mark_mode (void)
-{
-  return get_variable_bool ("transient-mark-mode");
-}
-
 void
 activate_mark (void)
 {
@@ -545,7 +539,7 @@ kill_buffer (Buffer * kill_bp)
 }
 
 DEFUN_ARGS ("kill-buffer", kill_buffer,
-            STR_ARG (buffer))
+            STR_ARG (buf))
 /*+
 Kill buffer BUFFER.
 With a nil argument, kill the current buffer.
@@ -553,24 +547,24 @@ With a nil argument, kill the current buffer.
 {
   Buffer *bp;
 
-  STR_INIT (buffer)
+  STR_INIT (buf)
   else
     {
       Completion *cp = make_buffer_completion ();
-      buffer = minibuf_read_completion ("Kill buffer (default %s): ",
-                                        "", cp, NULL, get_buffer_name (cur_bp));
+      buf = minibuf_read_completion ("Kill buffer (default %s): ",
+                                     "", cp, NULL, get_buffer_name (cur_bp));
       free_completion (cp);
-      if (buffer == NULL)
+      if (buf == NULL)
         ok = FUNCALL (keyboard_quit);
     }
 
-  if (buffer && buffer[0] != '\0')
+  if (buf && buf[0] != '\0')
     {
-      bp = find_buffer (buffer);
+      bp = find_buffer (buf);
       if (bp == NULL)
         {
-          minibuf_error ("Buffer `%s' not found", buffer);
-          free ((char *) buffer);
+          minibuf_error ("Buffer `%s' not found", buf);
+          free ((char *) buf);
           ok = leNIL;
         }
     }
@@ -585,7 +579,7 @@ With a nil argument, kill the current buffer.
         kill_buffer (bp);
     }
 
-  STR_FREE (buffer);
+  STR_FREE (buf);
 }
 END_DEFUN
 
