@@ -1,6 +1,6 @@
 /* Disk file handling
 
-   Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009 Free Software Foundation, Inc.
+   Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software Foundation, Inc.
 
    This file is part of GNU Zile.
 
@@ -19,17 +19,15 @@
    Free Software Foundation, Fifth Floor, 51 Franklin Street, Boston,
    MA 02111-1301, USA.  */
 
-#include "config.h"
+#include <config.h>
 
 #include <sys/stat.h>
-#include <assert.h>
 #include <errno.h>
 #include <fcntl.h>
 #include <limits.h>
 #include <pwd.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <string.h>
 #include <unistd.h>
 #include <utime.h>
 #include "dirname.h"
@@ -62,12 +60,12 @@ is_regular_file (const char *filename)
 astr
 agetcwd (void)
 {
-  char *s = getcwd (NULL, 0);
+  const char *s = getcwd (NULL, 0);
   astr as;
   if (s == NULL)
     s = "";
   as = astr_new_cstr (s);
-  free (s);
+  free ((char *) s);
   return as;
 }
 
@@ -127,7 +125,7 @@ expand_path (astr path)
                   ok = false;
                   break;
                 }
-              if (strcmp (pw->pw_dir, "/") != 0)
+              if (STRNEQ (pw->pw_dir, "/"))
                 astr_cat_cstr (epath, pw->pw_dir);
             }
           else
@@ -186,7 +184,7 @@ compact_path (astr path)
           !strncmp (pw->pw_dir, astr_cstr (path), homelen))
         {
           astr buf = astr_new_cstr ("~/");
-          if (!strcmp (pw->pw_dir, "/"))
+          if (STREQ (pw->pw_dir, "/"))
             astr_cat_cstr (buf, astr_cstr (path) + 1);
           else
             astr_cat_cstr (buf, astr_cstr (path) + homelen + 1);
@@ -353,7 +351,7 @@ find_file (const char *filename)
   for (bp = head_bp; bp != NULL; bp = get_buffer_next (bp))
     {
       if (get_buffer_filename (bp) != NULL &&
-          !strcmp (get_buffer_filename (bp), filename))
+          STREQ (get_buffer_filename (bp), filename))
         {
           switch_to_buffer (bp);
           return true;
@@ -450,34 +448,34 @@ If the current buffer now contains an empty file that you just visited
 END_DEFUN
 
 DEFUN_ARGS ("switch-to-buffer", switch_to_buffer,
-            STR_ARG (buffer))
+            STR_ARG (buf))
 /*+
 Select buffer @i{buffer} in the current window.
 +*/
 {
   Buffer *bp = ((get_buffer_next (cur_bp) != NULL) ? get_buffer_next (cur_bp) : head_bp);
 
-  STR_INIT (buffer)
+  STR_INIT (buf)
   else
     {
       Completion *cp = make_buffer_completion ();
-      buffer = minibuf_read_completion ("Switch to buffer (default %s): ",
-                                        "", cp, NULL, get_buffer_name (bp));
+      buf = minibuf_read_completion ("Switch to buffer (default %s): ",
+                                     "", cp, NULL, get_buffer_name (bp));
       free_completion (cp);
 
-      if (buffer == NULL)
+      if (buf == NULL)
         ok = FUNCALL (keyboard_quit);
     }
 
   if (ok == leT)
     {
-      if (buffer && buffer[0] != '\0')
+      if (buf && buf[0] != '\0')
         {
-          bp = find_buffer (buffer);
+          bp = find_buffer (buf);
           if (bp == NULL)
             {
               bp = buffer_new ();
-              set_buffer_name (bp, buffer);
+              set_buffer_name (bp, buf);
               set_buffer_needname (bp, true);
               set_buffer_nosave (bp, true);
             }
@@ -486,7 +484,7 @@ Select buffer @i{buffer} in the current window.
       switch_to_buffer (bp);
     }
 
-  STR_FREE (buffer);
+  STR_FREE (buf);
 }
 END_DEFUN
 
@@ -522,7 +520,7 @@ insert_buffer (Buffer * bp)
 }
 
 DEFUN_ARGS ("insert-buffer", insert_buffer,
-            STR_ARG (buffer))
+            STR_ARG (buf))
 /*+
 Insert after point the contents of BUFFER.
 Puts mark after the inserted text.
@@ -533,13 +531,13 @@ Puts mark after the inserted text.
   if (warn_if_readonly_buffer ())
     return leNIL;
 
-  STR_INIT (buffer)
+  STR_INIT (buf)
   else
     {
       Completion *cp = make_buffer_completion ();
-      buffer = minibuf_read_completion ("Insert buffer (default %s): ",
-                                        "", cp, NULL, get_buffer_name (def_bp));
-      if (buffer == NULL)
+      buf = minibuf_read_completion ("Insert buffer (default %s): ",
+                                     "", cp, NULL, get_buffer_name (def_bp));
+      if (buf == NULL)
         ok = FUNCALL (keyboard_quit);
       free_completion (cp);
     }
@@ -548,12 +546,12 @@ Puts mark after the inserted text.
     {
       Buffer *bp;
 
-      if (buffer && buffer[0] != '\0')
+      if (buf && buf[0] != '\0')
         {
-          bp = find_buffer (buffer);
+          bp = find_buffer (buf);
           if (bp == NULL)
             {
-              minibuf_error ("Buffer `%s' not found", buffer);
+              minibuf_error ("Buffer `%s' not found", buf);
               ok = leNIL;
             }
         }
@@ -564,7 +562,7 @@ Puts mark after the inserted text.
       set_mark_interactive ();
     }
 
-  STR_FREE (buffer);
+  STR_FREE (buf);
 }
 END_DEFUN
 
@@ -683,7 +681,10 @@ copy_file (const char *source, const char *dest)
 #ifdef HAVE_FCHMOD
       fchmod (ofd, st.st_mode);
 #endif
-      fchown (ofd, st.st_uid, st.st_gid);
+      if (fchown (ofd, st.st_uid, st.st_gid))
+        {
+          /* Avoid compiler warning for ignoring return value. */
+        }
     }
 
   close (ifd);
@@ -1069,7 +1070,7 @@ zile_exit (int doabort)
   if (doabort)
     abort ();
   else
-    exit (2);
+    exit (EXIT_CRASH);
 }
 
 DEFUN ("cd", cd)
