@@ -2,10 +2,10 @@
 (forward-char)
 (forward-char)
 (forward-char)
-(set-mark-command)
-(next-line)
-(next-line)
+(set-mark (point))
+(forward-line)
+(forward-line)
 (exchange-point-and-mark)
-(insert-char "f")
+(insert "f")
 (save-buffer)
-(save-buffers-kill-zile)
+(save-buffers-kill-emacs)
