@@ -1,5 +1,5 @@
 (forward-char)
 (forward-char)
-(delete-char)
+(delete-char 1)
 (save-buffer)
-(save-buffers-kill-zile)
+(save-buffers-kill-emacs)
