@@ -1,6 +1,6 @@
 /* Lisp lists
 
-   Copyright (c) 2008 Free Software Foundation, Inc.
+   Copyright (c) 2008, 2011 Free Software Foundation, Inc.
 
    This file is part of GNU Zile.
 
@@ -19,10 +19,9 @@
    Free Software Foundation, Fifth Floor, 51 Franklin Street, Boston,
    MA 02111-1301, USA.  */
 
-#include "config.h"
+#include <config.h>
 
 #include <stdlib.h>
-#include <string.h>
 
 #include "main.h"
 #include "extern.h"
