@@ -1,6 +1,6 @@
 /* Program invocation, startup and shutdown
 
-   Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 Free Software Foundation, Inc.
+   Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software Foundation, Inc.
 
    This file is part of GNU Zile.
 
@@ -19,17 +19,17 @@
    Free Software Foundation, Fifth Floor, 51 Franklin Street, Boston,
    MA 02111-1301, USA.  */
 
-#include "config.h"
+#include <config.h>
 
 #include <limits.h>
 #include <locale.h>
 #include <stdarg.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <string.h>
 #include <unistd.h>
 #include <getopt.h>
 #include <signal.h>
+#include "progname.h"
 #include "dirname.h"
 #include "gl_linked_list.h"
 
@@ -37,10 +37,7 @@
 #include "extern.h"
 
 #define ZILE_COPYRIGHT_STRING \
-  "Copyright (C) 2010 Free Software Foundation, Inc."
-
-/* The executable name */
-char *program_name = PACKAGE;
+  "Copyright (C) 2011 Free Software Foundation, Inc."
 
 /* The current window; the first window in list. */
 Window *cur_wp = NULL, *head_wp = NULL;
@@ -109,7 +106,7 @@ setup_main_screen (void)
 }
 
 static void
-segv_sig_handler (int signo GCC_UNUSED)
+_GL_ATTRIBUTE_NORETURN segv_sig_handler (int signo _GL_UNUSED_PARAMETER)
 {
   fprintf (stderr,
            "%s: " PACKAGE_NAME
@@ -120,7 +117,7 @@ segv_sig_handler (int signo GCC_UNUSED)
 }
 
 static void
-other_sig_handler (int signo GCC_UNUSED)
+_GL_ATTRIBUTE_NORETURN other_sig_handler (int signo _GL_UNUSED_PARAMETER)
 {
   fprintf (stderr, "%s: terminated with signal %d.\r\n",
            program_name, signo);
@@ -168,9 +165,7 @@ main (int argc, char **argv)
   astr as;
   bool ok = true;
 
-  /* Set program_name to executable name, if available */
-  if (argv[0])
-    program_name = base_name (argv[0]);
+  set_program_name (argv[0]);
 
   /* Set up Lisp environment now so it's available to files and
      expressions specified on the command-line. */
@@ -199,7 +194,7 @@ main (int argc, char **argv)
         {
           fprintf (stderr, "%s: Option `%s' requires an argument\n",
                    program_name, argv[this_optind]);
-          exit (1);
+          exit (EXIT_FAILURE);
         }
       else if (c == 'q')
         longindex = 0;
@@ -245,7 +240,7 @@ main (int argc, char **argv)
 #undef A
           printf ("\n"
                   "Report bugs to " PACKAGE_BUGREPORT ".\n");
-          exit (0);
+          exit (EXIT_SUCCESS);
         case 4:
           printf (ZILE_VERSION_STRING "\n"
                   ZILE_COPYRIGHT_STRING "\n"
@@ -253,7 +248,7 @@ main (int argc, char **argv)
                   "You may redistribute copies of " PACKAGE_NAME "\n"
                   "under the terms of the GNU General Public License.\n"
                   "For more information about these matters, see the file named COPYING.\n");
-          exit (0);
+          exit (EXIT_SUCCESS);
         case 5:
           if (*optarg == '+')
             line = strtoul (optarg + 1, NULL, 10);
@@ -265,6 +260,8 @@ main (int argc, char **argv)
               line = 1;
             }
           break;
+        default:
+          break;
         }
     }
 
@@ -292,7 +289,7 @@ main (int argc, char **argv)
 
   if (!qflag)
     {
-      astr as = get_home_dir ();
+      as = get_home_dir ();
       if (as)
         {
           astr_cat_cstr (as, "/." PACKAGE);
@@ -335,6 +332,8 @@ main (int argc, char **argv)
             lastflag |= FLAG_NEED_RESYNC;
           }
           break;
+        default:
+          break;
         }
       if (thisflag & FLAG_QUIT)
         break;
@@ -364,5 +363,5 @@ main (int argc, char **argv)
   /* Tidy and close the terminal. */
   term_finish ();
 
-  return 0;
+  return EXIT_SUCCESS;
 }
