@@ -1,6 +1,6 @@
 /* Marker facility functions
 
-   Copyright (c) 2004, 2008, 2009, 2010 Free Software Foundation, Inc.
+   Copyright (c) 2004, 2008, 2009, 2010, 2011 Free Software Foundation, Inc.
 
    This file is part of GNU Zile.
 
@@ -19,11 +19,10 @@
    Free Software Foundation, Fifth Floor, 51 Franklin Street, Boston,
    MA 02111-1301, USA.  */
 
-#include "config.h"
+#include <config.h>
 
 #include <stdlib.h>
 #include <ctype.h>
-#include <string.h>
 
 #include "main.h"
 #include "extern.h"
