@@ -1,6 +1,6 @@
 /* Minibuffer facility functions
 
-   Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2008, 2009, 2010 Free Software Foundation, Inc.
+   Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2008, 2009, 2010, 2011 Free Software Foundation, Inc.
 
    This file is part of GNU Zile.
 
@@ -19,13 +19,12 @@
    Free Software Foundation, Fifth Floor, 51 Franklin Street, Boston,
    MA 02111-1301, USA.  */
 
-#include "config.h"
+#include <config.h>
 
 #include <assert.h>
 #include <stdarg.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <string.h>
 
 #include "main.h"
 #include "extern.h"
@@ -187,16 +186,16 @@ minibuf_read_filename (const char *fmt, const char *value,
 
       if (p != NULL)
         {
-          astr as = astr_new_cstr (p);
-          if (expand_path (as))
+          astr bs = astr_new_cstr (p);
+          if (expand_path (bs))
             {
               add_history_element (files_history, p);
               free (p);
-              p = xstrdup (astr_cstr (as));
+              p = xstrdup (astr_cstr (bs));
             }
           else
             p = NULL;
-          astr_delete (as);
+          astr_delete (bs);
         }
     }
   astr_delete (as);
@@ -214,7 +213,8 @@ int
 minibuf_read_yn (const char *fmt, ...)
 {
   va_list ap;
-  char *buf, *errmsg = "";
+  char *buf;
+  const char *errmsg = "";
   int ret;
 
   va_start (ap, fmt);
@@ -268,8 +268,8 @@ minibuf_read_yesno (const char *fmt, ...)
       gl_list_node_t n = gl_sortedlist_search (get_completion_completions (cp),
                                                completion_strcmp, ms);
       assert (n);
-      ret = !strcmp ((char *) gl_list_node_value (get_completion_completions (cp), n),
-                     "yes");
+      ret = STREQ ((const char *) gl_list_node_value (get_completion_completions (cp), n),
+                   "yes");
     }
   free_completion (cp);
 
@@ -277,7 +277,7 @@ minibuf_read_yesno (const char *fmt, ...)
 }
 
 char *
-minibuf_read_completion (const char *fmt, char *value, Completion * cp,
+minibuf_read_completion (const char *fmt, const char *value, Completion * cp,
                          History * hp, ...)
 {
   va_list ap;
@@ -289,15 +289,15 @@ minibuf_read_completion (const char *fmt, char *value, Completion * cp,
 
   ms = term_minibuf_read (buf, value, SIZE_MAX, cp, hp);
 
- free (buf);
- return ms;
+  free (buf);
+  return ms;
 }
 
 /*
  * Read a string from the minibuffer using a completion.
  */
 char *
-minibuf_vread_completion (const char *fmt, char *value, Completion * cp,
+minibuf_vread_completion (const char *fmt, const char *value, Completion * cp,
                           History * hp, const char *empty_err,
                           bool (*test) (const char *s, gl_list_t completions),
                           const char *invalid_err, va_list ap)
